==> apache-tvm-src-v0.22.0.tar.gz: apache-tvm-src-v0.22.0/src/relax/op/image/resize.h <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*!
 * \file resize.h
 * \brief The functions to make Relax image resize operator calls.
 */

#ifndef TVM_RELAX_OP_IMAGE_RESIZE_H_
#define TVM_RELAX_OP_IMAGE_RESIZE_H_

#include <tvm/relax/attrs/image.h>

#include "../op_common.h"

namespace tvm {
namespace relax {

/*! \brief Image resize2d operator. */
Expr resize2d(Expr data, Expr size, ffi::Array<FloatImm> roi, ffi::String layout,
              ffi::String method, ffi::String coordinate_transformation_mode,
              ffi::String rounding_method, double cubic_alpha, int cubic_exclude,
              double extrapolation_value, ffi::Optional<DataType> out_dtype);

}  // namespace relax
}  // namespace tvm

#endif  // TVM_RELAX_OP_IMAGE_RESIZE_H_

==> apache-tvm-src-v0.23.0.tar.gz: apache-tvm-src-v0.23.0/src/relax/op/image/resize.h <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*!
 * \file resize.h
 * \brief The functions to make Relax image resize operator calls.
 */

#ifndef TVM_RELAX_OP_IMAGE_RESIZE_H_
#define TVM_RELAX_OP_IMAGE_RESIZE_H_

#include <tvm/relax/attrs/image.h>

#include "../op_common.h"

namespace tvm {
namespace relax {

/*! \brief Image resize2d operator. */
Expr resize2d(Expr data, Expr size, ffi::Array<FloatImm> roi, ffi::String layout,
              ffi::String method, ffi::String coordinate_transformation_mode,
              ffi::String rounding_method, double cubic_alpha, int cubic_exclude,
              double extrapolation_value, ffi::Optional<DataType> out_dtype);

/*! \brief Image grid_sample operator. */
Expr grid_sample(Expr data, Expr grid, ffi::String method, ffi::String layout,
                 ffi::String padding_mode, bool align_corners);

}  // namespace relax
}  // namespace tvm

#endif  // TVM_RELAX_OP_IMAGE_RESIZE_H_
